@@ -125,17 +125,27 @@ def _get_library_search_paths():
     Returns a list of library search paths, considering of the current working
     directory, default paths and paths from environment variables.
     """
+    package_path = os.path.abspath(os.path.dirname(__file__))
     search_paths = [
         '',
-        os.path.abspath(os.path.dirname(__file__)),
+        package_path,
         sys.prefix + '/lib',
         '/usr/lib64',
         '/usr/local/lib64',
         '/usr/lib', '/usr/local/lib',
         '/run/current-system/sw/lib',
-        '/usr/lib/x86_64-linux-gnu/'
+        '/usr/lib/x86_64-linux-gnu/',
+        '/usr/lib/aarch64-linux-gnu/',
     ]
 
+    if sys.platform != 'darwin':
+        # manylinux2014 wheels contain libraries built for X11 and Wayland
+        if os.environ.get('XDG_SESSION_TYPE') == 'wayland':
+            search_paths.insert(1, os.path.join(package_path, 'wayland'))
+        else:
+            # X11 is the default, even if XDG_SESSION_TYPE is not set
+            search_paths.insert(1, os.path.join(package_path, 'x11'))
+
     if sys.platform == 'darwin':
         path_environment_variable = 'DYLD_LIBRARY_PATH'
     else:
@@ -151,15 +161,33 @@ if os.environ.get('PYGLFW_LIBRARY', ''):
     except OSError:
         glfw = None
 elif sys.platform == 'win32':
-    # try glfw3.dll using windows search paths
+    glfw = None  # Will become `not None` on success.
+
+    # try Windows default search path
     try:
         glfw = ctypes.CDLL('glfw3.dll')
     except OSError:
-        # try glfw3.dll in package directory
+        pass
+
+    # try package directory
+    if glfw is None:
         try:
+            if sys.maxsize > 2**32:
+                # load Microsoft Visual C++ 2012 runtime on 64-bit systems
+                msvcr = ctypes.CDLL(os.path.join(os.path.abspath(os.path.dirname(__file__)), 'msvcr110.dll'))
+            else:
+                # load Microsoft Visual C++ 2010 runtime on 32-bit systems
+                msvcr = ctypes.CDLL(os.path.join(os.path.abspath(os.path.dirname(__file__)), 'msvcr100.dll'))
             glfw = ctypes.CDLL(os.path.join(os.path.abspath(os.path.dirname(__file__)), 'glfw3.dll'))
         except OSError:
-            glfw = None
+            pass
+
+    # try conda's default location on Windows
+    if glfw is None:
+        try:
+            glfw = ctypes.CDLL(os.path.join(sys.prefix, 'Library', 'bin', 'glfw3.dll'))
+        except OSError:
+            pass
 else:
     glfw = _load_library(['glfw', 'glfw3'], ['.so', '.dylib'],
                           _get_library_search_paths(), _glfw_get_version)
